# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 1
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir     qtquickeffectmaker-everywhere-src-%{qtversion}%{?pre:-%{pre}}

Name:           qtquickeffectmaker6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Tool for creating shader effects for Qt Quick
Group:          Development/KDE and Qt
License:        GPL-3.0-only
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
Source1:        org.qt.quickeffectmaker6.desktop
Source2:        org.qt.quickeffectmaker.png
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6Quick3DGlslParserPrivate) >= %{version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{version}

Provides:       qt%{qtmajor}-qtquickeffectmaker = %{version}-%{release}
Provides:       qtquickeffectmaker = %{version}-%{release}

%description
Qt Quick Effect Maker is a hybrid editor for creating shader effects for Qt
Quick applications and offers both a node editor and a code editor.

%files
%license LICENSES/* tools/qqem/qml/fonts/SourceCodePro.txt
%{_bindir}/qqem6
%{_bindir}/qqem-qt6
%{_datadir}/applications/org.qt.quickeffectmaker6.desktop
%{_iconsdir}/hicolor/128x128/apps/org.qt.quickeffectmaker.png
%{_qt6_bindir}/qqem
%{_qt6_qmldir}/QtQuickEffectMaker/
%if %{with examples}
%{_qt6_examplesdir}/quickeffectmaker/
%endif
%{_qt6_archdatadir}/sbom/qqeffectmaker-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtQuickEffectMaker%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtQuickEffectMaker%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtquickeffectmaker.qch
%{_qt6_docdir}/qtquickeffectmaker/
%endif

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtquickeffectmaker-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif

# Desktop file
desktop-file-install \
	        --dir %{buildroot}%{_datadir}/applications \
	        %{SOURCE1}
install -D -m644 %{SOURCE2} %{buildroot}%{_iconsdir}/hicolor/128x128/apps/org.qt.quickeffectmaker.png

# hardlink files to {_bindir}, add -qt6 postfix to not conflict
mkdir %{buildroot}%{_bindir}
pushd %{buildroot}%{_qt6_bindir}
ln -v qqem %{buildroot}%{_bindir}/qqem-qt6
ln -v qqem %{buildroot}%{_bindir}/qqem6


%changelog
* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2126009
- New version 6.8.1

* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103616
- New version 6.7.3
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083114
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072549
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Thu May 23 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2066228
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041648
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999043
- New version 6.6.0

* Sun Sep 24 2023 daviddavid <daviddavid> 6.5.2-1.mga10
+ Revision: 1989934
- initial package qtquickeffectmaker6

